summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/components/ContactDetails.vue4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/components/ContactDetails.vue b/src/components/ContactDetails.vue
index 35e17ed8..1c39e260 100644
--- a/src/components/ContactDetails.vue
+++ b/src/components/ContactDetails.vue
@@ -752,10 +752,10 @@ export default {
},
/**
* Select the text in the input if it is still set to 'new Contact'
*/
selectInput() {
- if (this.$refs.fullname && this.$refs.fullname.value === t('contacts', 'New contact')) {
+ if (this.$refs.fullname && this.$refs.fullname.value === t('contacts', 'Name')) {
this.$refs.fullname.select()
}
},
@@ -752,10 +752,10 @@ export default {
},
/**
- * Select the text in the input if it is still set to 'new Contact'
+ * Select the text in the input if it is still set to 'Name'
*/
selectInput() {